Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Styler ¶
Styler stores and serves styles classes are created dynamicaly with ULID
func New ¶
func New() *Styler
New create new styler, sets its url Styler.Handler() can be used with any other url too
func (*Styler) Handler ¶
func (st *Styler) Handler() http.HandlerFunc
Handler creates new http handler it recreates styles on every request no caching is done recommended to be used with Styler.ID or Styler.Url as path
Click to show internal directories.
Click to hide internal directories.